.. _raven:

yt.raven - Data Plotting and Display
====================================

.. module:: yt.raven
   :synopsis: The plotting backend for yt
.. moduleauthor:: Matthew Turk <mturk@stanford.edu>

This is an API documentation generated from a subset of the docstrings for this
module.  Many of the things that happen behind the scenes are not included; it
is primarily meant to be a guide to using the module, not necessarily extending
it.

.. toctree::
   :maxdepth: 2

   plotcollection
   plot3dinterface
